Introduction

# XMLRésuméLibrary: User Guide

XML Résumé Library User Guide | XML Résumé Library User Guide | Part I. Getting Started

# Introduction

## What is the XML Résumé Library?

The XML Résumé Library is, at its heart, a DTD, a Document Type Definition. That means it is really someone's idea of how a résumé should, or at least could, be structured in XML. Beyond that, it comes with

- Several XSLT style sheets (used to convert the XML version of a résumé to other formats such as plaintext, HTML, PDF, and if you're lucky, RTF).

- A Java-based filter to help you target your résumé(s) toward a particular industry, employer, or job.

- CSS stylesheets, used to control the presentation of the HTML version.

- A helpful `Makefile` that you can customize for your own purposes.

XML Résumé Library User Guide | XML Résumé Library User Guide | Part I. Getting Started